#!/usr/bin/env python3

import os
import shutil
import sys

from gi.repository import GExiv2

def rename(prefix, dirpath, fname):
    """Do the renaming."""
    ext = fname.split(".")[-1]
    fullpath_src = os.path.join(dirpath, fname)
    metadata = GExiv2.Metadata(fullpath_src)

    try:
        dt = metadata['Exif.Photo.DateTimeOriginal']
    except KeyError:
        dt = metadata['Exif.Image.DateTime']
    dt = dt.replace(":", "").replace(" ", "-")

    # move!
    new_fname = prefix + dt + "." + ext
    fullpath_dst = os.path.join(dirpath, new_fname)
    print("Moviendo", repr(fullpath_src), repr(fullpath_dst))
    shutil.move(fullpath_src, fullpath_dst)


def main(prefix, direct):
    """Main entry point."""
    if not os.path.exists(direct):
        print("Error: El dir {!r} no existe".format(direct))
        exit()

    for dirpath, dirnames, filenames in os.walk(direct):
        for fname in filenames:
            try:
                rename(prefix, dirpath, fname)
            except Exception as err:
                print("ERROR while working with", repr(fname))
                raise


if __name__ == '__main__':
    from argparse import ArgumentParser
    parser = ArgumentParser(description="Rename photos to a prefix+tstamp")
    parser.add_argument("prefix")
    parser.add_argument("directory")
    args = parser.parse_args()

    main(args.prefix, args.directory)
